Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2510)

Unified Diff: cc/surfaces/referenced_surface_tracker.h

Issue 2661543002: Rename LocalFrameId to LocalSurfaceId (Closed)
Patch Set: c Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/surfaces/local_surface_id.cc ('k') | cc/surfaces/referenced_surface_tracker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/surfaces/referenced_surface_tracker.h
diff --git a/cc/surfaces/referenced_surface_tracker.h b/cc/surfaces/referenced_surface_tracker.h
index 19e17f3d4d276c30e67bbe35cc1646cb12c7a41c..395a853ecbb4343052d24180479247fb211b5e38 100644
--- a/cc/surfaces/referenced_surface_tracker.h
+++ b/cc/surfaces/referenced_surface_tracker.h
@@ -34,12 +34,12 @@ class CC_SURFACES_EXPORT ReferencedSurfaceTracker {
return references_to_remove_;
}
// Update the references for a CompositorFrame. If |local_frame_id| has
// changed then new references will be generated for everything in
// |referenced_surfaces|. Otherwise a diff from the referenced surfaces in the
// last frame will be computed. This should be called once per
// CompositorFrame.
- void UpdateReferences(const LocalFrameId& local_frame_id,
+ void UpdateReferences(const LocalSurfaceId& local_surface_id,
const std::vector<SurfaceId>& referenced_surfaces);
private:
« no previous file with comments | « cc/surfaces/local_surface_id.cc ('k') | cc/surfaces/referenced_surface_tracker.cc » ('j') | no next file with comments »
@@ -34,12 +34,12 @@ class CC_SURFACES_EXPORT ReferencedSurfaceTracker {
return references_to_remove_;
}
- // Update the references for a CompositorFrame. If |local_frame_id| has
+ // Update the references for a CompositorFrame. If |local_surface_id| has
// changed then new references will be generated for everything in
// |referenced_surfaces|. Otherwise a diff from the referenced surfaces in the

Powered by Google App Engine
This is Rietveld 408576698